@@ -4,7 +4,6 @@ from django.utils.decorators import method_decorator
 from django.views.decorators.csrf import csrf_exempt
 from furl import furl
 from django.views.generic import View
-from json import loads as unjsonize
 from crud_framework.errors import Error
 
 
@@ -25,7 +24,7 @@ def view_catch_error(f):
             except:
                 filters = {}
 
-            return f(request=request, filters=filters, *args, **kwargs)
+            return f(filters=filters, *args, **kwargs)
         except Error as e:
             return JsonResponse(status=e.status, data=dict(e))
         except Exception as e:
@@ -62,46 +61,59 @@ class BaseView(View):
         else:
             return HttpResponse(status=204)
 
-    def get(self, request, filters):
+    def get(self, filters):
         raise NotImplemented('GET not Allowed!')
 
-    def post(self, request, filters, **kwargs):
+    def post(self, body, filters, **kwargs):
         raise NotImplemented('POST not Allowed!')
 
-    def put(self, request, filters, **kwargs):
+    def put(self, body, filters, **kwargs):
         raise NotImplemented('PUT not Allowed!')
 
-    def delete(self, request, filters, **kwargs):
+    def delete(self, filters, **kwargs):
         raise NotImplemented('DELETE not Allowed!')
 
 
 class BaseCrudView(BaseView):
 
-    def get(self, request, filters, **kwargs):
+    def get(self, filters, **kwargs):
         crud = self.schema_class(filters=filters, initkwargs=kwargs.pop('initkwargs', {}))
         self.data = crud.get()
         return self._respond()
 
-    def post(self, request, filters, **kwargs):
+    def post(self, body, filters, **kwargs):
         print('in post')
         crud = self.schema_class(filters=filters, initkwargs=kwargs.pop('initkwargs', {}))
-        body = unjsonize(request.body.decode())
+
+        for k, v in kwargs.pop('files', {}).items():
+            # print(v.__dict__) todo change content from b''
+            # with open('tmp') as t:
+            #     t.write(v['file'].read())
+            #     print(t.__dict__)
+            body[k] = v
+
         self.data = crud.post(**body, **kwargs)
         return self._respond()
 
-    def bulk_post(self, request, filters, **kwargs):
+    def bulk_post(self, body, filters, **kwargs):
         crud = self.schema_class(filters=filters, initkwargs=kwargs.pop('initkwargs', {}))
-        body = unjsonize(request.body.decode())
+
+        for k, v in kwargs.pop('files', {}).items():
+            body[k] = v
+
         self.data = crud.bulk_post(data=body, **filters, **kwargs)
         return self._respond()
 
-    def put(self, request, filters, **kwargs):
+    def put(self, body, filters, **kwargs):
         crud = self.schema_class(filters=filters, initkwargs=kwargs.pop('initkwargs', {}))
-        body = unjsonize(request.body.decode())
+
+        for k, v in kwargs.pop('files', {}).items():
+            body[k] = v
+
         self.data = crud.put(**body, **kwargs)
         return self._respond()
 
-    def delete(self, request, filters, **kwargs):
+    def delete(self, filters, **kwargs):
         crud = self.schema_class(filters=filters, initkwargs=kwargs.pop('initkwargs', {}))
         if not crud.delete():
             return HttpResponse(status=404)
@@ -110,4 +122,4 @@ class BaseCrudView(BaseView):
     @classmethod
     def get_doc(cls, request):
         crud = cls.SCHEMA_CLASS({})
-        return render(request, crud.template_path)
+        return render(crud.template_path)
